---
orphan: true
---

# Tutorials

The easiest way to get familiar with ehrdata is to follow along with our tutorials.
Many are also designed to work seamlessly in Binder, a free cloud computing platform.

**The notebooks can be followed in this order:**

1. **[Getting Started](getting_started)** - Learn the basics of the `EHRData` data structure
2. **[Real Dataset Example: PhysioNet 2019](real_dataset_example_physionet2019)** - Work with a public clinical dataset
3. **[OMOP Introduction](omop_intro)** - Learn how to read OMOP data into `EHRData`
4. **[OMOP Machine Learning](omop_ml)** - Quickstart to ML workflows based on an OMOP dataset
5. **[Interactive Visualization](interactive_visualization)** - Explore your data interactively with Vitessce
6. **[Advanced: Data Management with LaminDB](lamin)** - Store, share, and track datasets in the cloud

```{toctree}
:maxdepth: 2

getting_started
real_dataset_example_physionet2019
omop_intro
omop_ml
interactive_visualization
lamin
```
